function build_read_function_pointer_table(xml_database_version, side)

% Copyright (c) 2007-2014 University of Wisconsin Regents.
%
% This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.

% build a table of handles to the reader functions. To read a packet with a given
% APID, call the reader function like this:
%
%    g_read_function_pointer_table{apid - 1279}();

set_globals

MIN_APID = 1280;
MAX_APID = 1400;

g_read_function_pointer_table = cell(MAX_APID - MIN_APID + 1, 1);

% initialize table
g_read_function_pointer_table(:) = {str2func('read_unknown_packet')};

% replace '.' with '_' in version tag in function and file names 
version_suffix = strrep(xml_database_version, '.', '_');

% HK1 through 8
g_read_function_pointer_table(1280 - MIN_APID + 1) = {str2func(['read_packet_instr_hk1_data_', version_suffix])};
g_read_function_pointer_table(1281 - MIN_APID + 1) = {str2func(['read_packet_instr_hk2_data_', version_suffix])};
g_read_function_pointer_table(1282 - MIN_APID + 1) = {str2func(['read_packet_instr_hk3_data_', version_suffix])};
g_read_function_pointer_table(1283 - MIN_APID + 1) = {str2func(['read_packet_instr_hk4_data_', version_suffix])};
g_read_function_pointer_table(1284 - MIN_APID + 1) = {str2func(['read_packet_instr_hk5_data_', version_suffix])};
g_read_function_pointer_table(1285 - MIN_APID + 1) = {str2func(['read_packet_instr_hk6_data_', version_suffix])};
g_read_function_pointer_table(1286 - MIN_APID + 1) = {str2func(['read_packet_instr_hk7_data_', version_suffix])};
g_read_function_pointer_table(1287 - MIN_APID + 1) = {str2func(['read_packet_instr_hk8_data_', version_suffix])};

% 8-sec sci
g_read_function_pointer_table(1289 - MIN_APID + 1) = {str2func(['read_packet_eight_sec_sci_side', int2str(side) , '_data_', version_suffix])};

% 4-min eng
g_read_function_pointer_table(1290 - MIN_APID + 1) = {str2func(['read_packet_four_min_eng_data_', version_suffix])};

% LW, MW and SW Diagnostic
g_read_function_pointer_table(1294 - MIN_APID + 1) = {str2func(['read_packet_lw_diag_data_', version_suffix])};
g_read_function_pointer_table(1295 - MIN_APID + 1) = {str2func(['read_packet_mw_diag_data_', version_suffix])};
g_read_function_pointer_table(1296 - MIN_APID + 1) = {str2func(['read_packet_sw_diag_data_', version_suffix])};

% interferogram RDR 
bands = {'lw', 'mw', 'sw'};
scenes = {'es', 'ds', 'ict'};

% Matlab can't do integer math like every other language in the world
for apid = 1315:1395
    idx = int32(apid) - MIN_APID + 1;
    band = bands{mod(idivide(int32(apid) - 1315, 9), 3) + 1};
    fov = int2str(mod(int32(apid) - 1315, 9) + 1);
    scene = scenes{idivide(int32(apid) - 1315, 27) + 1};
    g_read_function_pointer_table(idx) = {str2func(['read_packet_ifg_', band, '_fov', fov, '_', scene, '_data_', version_suffix])};
end

% HK Dwell
g_read_function_pointer_table(1291 - MIN_APID + 1) = {str2func(['read_packet_hk_dwell_data_', version_suffix])};
