function initialize_packet_structures()

% Copyright (c) 2007-2014 University of Wisconsin Regents.
%
% This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.

set_globals
       
% Initialize packet structures

% FUTURE: use constants throughout this file

% preallocate space for Interferogram RDR data to increase speed
% FIXME: evaluate performance benefits of pre-allocating space for
% interferogram RDR arrays. Requires guessing number and size of 
% interferograms that will be read, but should be the same for 
% operational data, at least. Disadvantage is that there will 
% be a cost incurred if the guess is wrong or if there are no
% interterferogram RDR packets.

% These are Dan Mooney's preallocated sizes. Should compare this
% to the actual sizes in the .mat files. Also make sure the type
% matches the type read in by the readers.
% $$$ in.LWES.ifg_real=zeros(9,866,1000,'double');
% $$$ in.MWES.ifg_real=zeros(9,530,1000,'double');
% $$$ in.SWES.ifg_real=zeros(9,202,1000,'double');;
% $$$ in.LWSP.ifg_real=zeros(9,866,520,'double');
% $$$ in.MWSP.ifg_real=zeros(9,530,520,'double');
% $$$ in.SWSP.ifg_real=zeros(9,202,520,'double');
% $$$ in.LWIT.ifg_real=zeros(9,866,520,'double');
% $$$ in.MWIT.ifg_real=zeros(9,530,520,'double');
% $$$ in.SWIT.ifg_real=zeros(9,202,520,'double');
% $$$ in.LWES.ifg_imag=zeros(9,866,1000,'double');
% $$$ in.MWES.ifg_imag=zeros(9,530,1000,'double');
% $$$ in.SWES.ifg_imag=zeros(9,202,1000,'double');
% $$$ in.LWSP.ifg_imag=zeros(9,866,520,'double');
% $$$ in.MWSP.ifg_imag=zeros(9,530,520,'double');
% $$$ in.SWSP.ifg_imag=zeros(9,202,520,'double');
% $$$ in.LWIT.ifg_imag=zeros(9,866,520,'double');
% $$$ in.MWIT.ifg_imag=zeros(9,530,520,'double');
% $$$ in.SWIT.ifg_imag=zeros(9,202,520,'double');

% initialize packet counters
for band = {'lw', 'mw', 'sw'}
    for fov = 1:9
        for scene = {'ds', 'es', 'ict'}
            g_metadata.packet_stats.num_packets.(strcat('ifg_',char(band),'_fov', int2str(fov),'_',char(scene))) = 0;
        end
    end
end
g_metadata.packet_stats.num_packets.four_min_eng = 0;
g_metadata.packet_stats.num_packets.eight_sec_sci = 0;
g_metadata.packet_stats.num_packets.instr_hk1 = 0;
g_metadata.packet_stats.num_packets.instr_hk2 = 0;
g_metadata.packet_stats.num_packets.instr_hk3 = 0;
g_metadata.packet_stats.num_packets.instr_hk4 = 0;
g_metadata.packet_stats.num_packets.instr_hk5 = 0;
g_metadata.packet_stats.num_packets.instr_hk6 = 0;
g_metadata.packet_stats.num_packets.instr_hk7 = 0;
g_metadata.packet_stats.num_packets.instr_hk8 = 0;
g_metadata.packet_stats.num_packets.lw_diag = 0;
g_metadata.packet_stats.num_packets.mw_diag = 0;
g_metadata.packet_stats.num_packets.sw_diag = 0;
g_metadata.packet_stats.num_packets.hk_dwell = 0;
g_metadata.packet_stats.num_packets.unknown = 0;



